@@ -1,21 +1,32 @@
-use core::convert::{TryFrom, TryInto};
+//! PKCS#8 version identifier.
 
-use der::{Encodable, Encoder, Tagged};
+use core::convert::{TryFrom, TryInto};
+use der::{asn1::Any, Encodable, Encoder, Tag, Tagged};
 
 use crate::Error;
 
-/// Version marker for PKCS#8 documents.
+/// Version identifier for PKCS#8 documents.
 ///
 /// (RFC 5958 designates `0` and `1` as the only valid versions for PKCS#8 documents)
 #[derive(Clone, Debug, Copy, PartialEq)]
 pub enum Version {
-    /// Denotes PKCS#8 v1, used for [`crate::PrivateKeyInfo`] and [`crate::OneAsymmetricKey`]
+    /// Denotes PKCS#8 v1: no public key field.
     V1 = 0,
 
-    /// Denotes PKCS#8 v2, only used for [`crate::OneAsymmetricKey`]
+    /// Denotes PKCS#8 v2: `OneAsymmetricKey` with public key field.
     V2 = 1,
 }
 
+impl Version {
+    /// Is this version expected to have a public key?
+    pub fn has_public_key(self) -> bool {
+        match self {
+            Version::V1 => false,
+            Version::V2 => true,
+        }
+    }
+}
+
 impl From<Version> for u8 {
     fn from(version: Version) -> Self {
         version as u8
@@ -28,20 +39,17 @@ impl TryFrom<u8> for Version {
         match byte {
             0 => Ok(Version::V1),
             1 => Ok(Version::V2),
-            _ => Err(Error::Decode),
+            _ => Err(Self::TAG.value_error().into()),
         }
     }
 }
 
-impl<'a> TryFrom<der::Any<'a>> for Version {
+impl<'a> TryFrom<Any<'a>> for Version {
     type Error = der::Error;
-    fn try_from(any: der::Any<'a>) -> der::Result<Version> {
-        u8::try_from(any)?.try_into().map_err(|_| {
-            der::ErrorKind::Value {
-                tag: der::Tag::Integer,
-            }
-            .into()
-        })
+    fn try_from(any: Any<'a>) -> der::Result<Version> {
+        u8::try_from(any)?
+            .try_into()
+            .map_err(|_| Self::TAG.value_error())
     }
 }
 
@@ -52,11 +60,10 @@ impl Encodable for Version {
 
     fn encode(&self, encoder: &mut Encoder<'_>) -> der::Result<()> {
         der::Header::new(Self::TAG, 1u8)?.encode(encoder)?;
-
         encoder.encode(self)
     }
 }
 
 impl Tagged for Version {
-    const TAG: der::Tag = der::Tag::Integer;
+    const TAG: Tag = Tag::Integer;
 }
